@@ -29,6 +29,7 @@ import metator.io as mio
 def alignment_to_contacts(
     alignment_files,
     contig_data,
+    edge,
     hit_data,
     out_dir,
     output_file_network,
@@ -54,6 +55,9 @@ def alignment_to_contacts(
         are the keys to the data of the contig available with the following
         keys: "id", "length", "GC", "hit", "coverage". Coverage still at 0 and
         need to be updated later.
+    edge : int
+        Distance of the edge region in base pair on the contigs where the
+        mapping reads are not considered as inter contigs.
     hit_data : dict:
         Dictionnary for hit information on each contigs.
     out_dir : str
@@ -88,12 +92,12 @@ def alignment_to_contacts(
     contig_data_file = join(out_dir, output_file_contig_data)
     hit_data_file = join(out_dir, "hit_data_alignment.txt")
     nb_alignment = len(alignment_files)
-    logger.info("New time course network")
 
     # Create a contact file easily readable for counting the contacts.
     contig_data, out_files_list = precompute_network(
         alignment_files,
         contig_data,
+        edge,
         hit_data,
         precompute_network_file,
         tmp_dir,
@@ -182,7 +186,7 @@ def compute_network(
     n_nonzero = 1  # Total number of nonzero matrix entries
     n_pairs = 0  # Total number of pairs entered in the matrix
 
-    # Read the sorted paors
+    # Read the sorted pairs
     with open(tmp_file, "r") as pairs, open(network_file, "w") as net:
         pairs_reader = csv.reader(pairs, delimiter="\t")
         prev_pair = next(pairs_reader)
@@ -249,7 +253,7 @@ def compute_network(
         n_pairs += n_occ
 
 
-def create_contig_data(assembly, nb_alignment, depth_file, enzyme):
+def create_contig_data(assembly, nb_alignment=1, depth_file=None, enzyme=None):
     """Create a dictionnary with data on each Contig.
 
     Parameters:
@@ -257,12 +261,13 @@ def create_contig_data(assembly, nb_alignment, depth_file, enzyme):
     assembly : str
         Path to the assembly fasta file
     nb_alignement : int
-        Numbers of alignment files.
+        Numbers of alignment files.  [Default: 1]
     depth_file : str or None
         Path to the depth.txt file from jgi_summarize_bam_contig_depths from
-        Metabat2 Software.
+        Metabat2 Software. [Default: None]
     enzyme : str or None
         String that contains the names of the enzyme separated by a comma.
+        [Default: None]
 
     Returns:
     --------
@@ -343,7 +348,7 @@ def normalize_pair(contig_data, pair, n_occ, normalization):
     pair : tuple
         Tuple of the id of the contigs contributing to the contact.
     n_occ : int
-        Contac count between the two contigs.
+        Contact count between the two contigs.
     normalization : str
         Mode of normalization to use.
 
@@ -397,9 +402,9 @@ def normalize_pair(contig_data, pair, n_occ, normalization):
                 contig_data[pair[1]]["length"] * contig_data[pair[1]]["RS"]
             )
         )
-        # If no read mapped from Shotgun libraries could be equal to zero.
-        if factor == 0:
-            return 0
+    # If no read mapped from Shotgun libraries could be equal to zero.
+    if factor == 0:
+        return 0
 
     return n_occ / factor
 
@@ -407,6 +412,7 @@ def normalize_pair(contig_data, pair, n_occ, normalization):
 def precompute_network(
     alignment_files,
     contig_data,
+    edge,
     hit_data,
     out_file,
     tmp_dir,
@@ -425,11 +431,16 @@ def precompute_network(
         are the keys to the data of the contig available with the following
         keys: "id", "length", "GC", "hit", "coverage". Coverage still at 0 and
         need to be updated later.
+    edge : int
+        Distance of the edge region in base pair on the contigs where the
+        mapping reads are not considered as inter contigs.
     hit_data : dict
         Dictionnary with the count of hits for each aligment file.
     out_file : str
         Path to the write the output_file which will be necessary to compute the
         network.
+    tmp_dir : str
+        Directory where to store temporary files.
     self_contacts : bool
         If True, the contacts on the same contigs will be kept. Otherwise only
         displays the inter contigs contacts. [Default False]
@@ -459,9 +470,8 @@ def precompute_network(
             out_files_list.append(out_file_sample)
 
             # Read the alignment_file and build pairs for the network
-            with open(aligment_file, "r") as pairs, open(
-                out_file_sample, "w"
-            ) as pre_net_sample:
+            pairs = mio.read_compressed(aligment_file)
+            with open(out_file_sample, "w") as pre_net_sample:
                 for pair in pairs:
                     # Ignore header lines
                     if pair.startswith("#"):
@@ -473,6 +483,9 @@ def precompute_network(
                     # Extract the contig names which are at the position 2 and
                     # 4.
                     contig1, contig2 = p[1], p[3]
+                    pos1, pos2 = int(p[2]), int(p[4])
+                    len1 = contig_data[contig1]["length"]
+                    len2 = contig_data[contig2]["length"]
                     id1 = contig_data[contig1]["id"]
                     id2 = contig_data[contig2]["id"]
 
@@ -485,46 +498,71 @@ def precompute_network(
                         hit_data[contig2]["hit"][i] += 1
 
                     # Write the file used for the computation of the network.
-                    if self_contacts and id1 == id2:
-                        pre_net.write(
-                            "\t".join(map(str, [contig1, contig2])) + "\n"
-                        )
-                        pre_net_sample.write(
-                            "\t".join(map(str, [contig1, contig2])) + "\n"
-                        )
-                    elif id1 < id2:
-                        inter_contacts_temp += 1
-                        pre_net.write(
-                            "\t".join(map(str, [contig1, contig2])) + "\n"
-                        )
-                        pre_net_sample.write(
-                            "\t".join(map(str, [contig1, contig2])) + "\n"
-                        )
-                    elif id1 > id2:
-                        inter_contacts_temp += 1
-                        pre_net.write(
-                            "\t".join(map(str, [contig2, contig1])) + "\n"
-                        )
-                        pre_net_sample.write(
-                            "\t".join(map(str, [contig2, contig1])) + "\n"
-                        )
+                    # Write all pairs if self contacts.
+                    if self_contacts:
+                        if id1 == id2:
+                            pre_net.write(
+                                "\t".join(map(str, [contig1, contig2])) + "\n"
+                            )
+                            pre_net_sample.write(
+                                "\t".join(map(str, [contig1, contig2])) + "\n"
+                            )
+                        if id1 < id2:
+                            inter_contacts_temp += 1
+                            pre_net.write(
+                                "\t".join(map(str, [contig1, contig2])) + "\n"
+                            )
+                            pre_net_sample.write(
+                                "\t".join(map(str, [contig1, contig2])) + "\n"
+                            )
+                        elif id1 > id2:
+                            inter_contacts_temp += 1
+                            pre_net.write(
+                                "\t".join(map(str, [contig2, contig1])) + "\n"
+                            )
+                            pre_net_sample.write(
+                                "\t".join(map(str, [contig2, contig1])) + "\n"
+                            )
+                    # Write only intercontigs pairs with both reads not mapping
+                    # on the edges of the contigs (defined by edge).
+                    else:
+                        if (
+                            (pos1 > edge)
+                            and (pos2 > edge)
+                            and (len1 - pos1 > edge)
+                            and (len2 - pos2 > edge)
+                        ):
+                            if id1 < id2:
+                                inter_contacts_temp += 1
+                                pre_net.write(
+                                    "\t".join(map(str, [contig1, contig2]))
+                                    + "\n"
+                                )
+                                pre_net_sample.write(
+                                    "\t".join(map(str, [contig1, contig2]))
+                                    + "\n"
+                                )
+                            elif id1 > id2:
+                                inter_contacts_temp += 1
+                                pre_net.write(
+                                    "\t".join(map(str, [contig2, contig1]))
+                                    + "\n"
+                                )
+                                pre_net_sample.write(
+                                    "\t".join(map(str, [contig2, contig1]))
+                                    + "\n"
+                                )
 
             # Count contacts and return sample informations.
             all_contacts += all_contacts_temp
             inter_contacts += inter_contacts_temp
-            logger.info("Information of {0}:".format(basename(aligment_file)))
+            logger.info(f"Information of {basename(aligment_file)}:")
+            logger.info(f"{all_contacts_temp} contacts in the library.")
             logger.info(
-                "{0} contacts in the library.".format(all_contacts_temp)
+                f"{inter_contacts_temp} contacts inter-contigs in the library."
             )
             logger.info(
-                "{0} contacts inter-contigs in the library.".format(
-                    inter_contacts_temp
-                )
-            )
-            logger.info(
-                "3D ratio : {0}\n".format(
-                    inter_contacts_temp / all_contacts_temp
-                )
+                f"3D ratio : {inter_contacts_temp / all_contacts_temp}\n"
             )
 
     # Return information about the network
